<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://codecanyon.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Built_It
 * @subpackage Built_It/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Built_It
 * @subpackage Built_It/admin
 * @author     Kamlesh Yadav <#>
 */
class Built_It_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Built_It_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Built_It_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/built-it-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Built_It_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Built_It_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/built-it-admin.js', array( 'jquery' ), $this->version, false );
	}

}

/** 
 * WPBakery Page Builder Add Shortcode
 */ 
require_once 'partials/built-it-admin-display.php';

/** 
 * Gallery Custom Post Type
 */  
require_once 'cpt/built-it-cpt.php'; 

/** 
 * Category Thumbnail Image
 */ 
require_once 'built-it-texo-thumb.php';

/** 
 * Admin Notice
 */ 
function builtit_admin_notice_success() {
    if ( is_plugin_active( 'js_composer/js_composer.php' ) ) {
        ?>
         <div class="notice notice-success is-dismissible">
             <p><b><?php esc_html_e( 'Hurray', 'built-it' ); ?></b> <?php esc_html_e( 'You Can Use The Built It Shortcodes Plugin.', 'built-it' ); ?></p>
         </div>
    <?php
        }else{ 
            
            ?>
         <div class="notice notice-success is-dismissible">
              <p><?php esc_html_e( 'You need to install', 'built-it' ); ?><b><?php esc_html_e( ' WP Bakery Page Builder', 'built-it' ); ?></b>. <?php esc_html_e( 'Please Activate if already installed', 'built-it' ); ?></p>
         </div>
    <?php
        }
    }
add_action( 'admin_notices', 'builtit_admin_notice_success' );