<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://codecanyon.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Built_It
 * @subpackage Built_It/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Built_It
 * @subpackage Built_It/public
 * @author     Kamlesh Yadav <#>
 */
class Built_It_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Built_It_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Built_It_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style( 'all', plugin_dir_url( __FILE__ ) . 'css/all.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'bootstrap', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'font', plugin_dir_url( __FILE__ ) . 'css/font.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'magnific-popup', plugin_dir_url( __FILE__ ) . 'css/magnific-popup.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'swiper', plugin_dir_url( __FILE__ ) . 'css/swiper.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/built-it-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Built_It_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Built_It_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script( 'bootstrap', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array('jquery'), $this->version, 'all' );
		wp_enqueue_script( 'magnific-popup', plugin_dir_url( __FILE__ ) . 'js/magnific-popup.min.js', array('jquery'), $this->version, 'all' );
		wp_enqueue_script( 'SmoothScroll', plugin_dir_url( __FILE__ ) . 'js/SmoothScroll.min.js', array('jquery'), $this->version, 'all' );
		wp_enqueue_script( 'swiper-bundle.min', plugin_dir_url( __FILE__ ) . 'js/swiper-bundle.min.js', array('jquery'), $this->version, 'all' );
		wp_enqueue_script( 'swiper', plugin_dir_url( __FILE__ ) . 'js/swiper.min.js', array('jquery'), $this->version, 'all' );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/built-it-public.js', array( 'jquery' ), $this->version, false );

	}

}

/** 
 * WPBakery Page Builder Add Shortcode
 */ 
 
require_once 'partials/built-it-public-display.php'; 

/**
 * Return Attachment Image
*/
function built_it_get_the_image($attach_id, $size){
	$image = wp_get_attachment_image_src($attach_id, 'full');
	$image_alt = get_post_meta($attach_id, '_wp_attachment_image_alt', TRUE);
	if(empty($image_alt)){
		
		$image_alt = get_the_title(get_the_ID());
	}
	if(!empty($image)){
		return '<img src="'.esc_url($image[0]).'" alt="'.esc_attr($image_alt).'"/>';
	}else{
		return '';
	}
}
