jQuery(document).ready(function ($) {
	'use strict';
	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */
	 var builtit = {
		initialised: false,
		version: 1.0,
		init: function () {

			if(!this.initialised) {
				this.initialised = true;
			} else {
				return;
			}

			// Functions Calling

			this.popup();
			this.image_slider();
			this.testimonial_slider();
			this.counter_timer();
			this.blog_slider();
			this.countdown_timer();
			this.accordion();
			this.category_slider();

		},

			// popup start
			popup: function () {
				if($('.builtit-play-btn').length > 0){
					$('.builtit-popup-video').magnificPopup({
					disableOn: 700,
					type: 'iframe',
					mainClass: 'mfp-fade',
					removalDelay: 160,
					preloader: false,
					fixedContentPos: false
					});
				};
				if($('.builtit-img-gallery-overlay').length > 0){
					$('.builtit-magnific-image').magnificPopup({
						type: 'image',
						gallery: {
							enabled: true
						}
					});
				};
				if($('body').length > 0){
				    $('.builtit-popup-video').on('click', function() {
				    var meta = $(this).attr('data-popmeta');
				    var data = meta != undefined ? JSON.parse(meta) : '';
				        console.log(data);
				        $(".mfp-bg").css({"background-color": data.screen});
				        $(".mfp-image-holder .mfp-close, .mfp-iframe-holder .mfp-close").css({"color": data.btn_color, "background-color": data.btn_bg });
				        $(".mfp-iframe-scaler iframe, .mfp-figure img").css({"border-width": data.border, "border-color": data.bcolor, "border-radius": data.radius});
				    });
				};
			},
			// popup end
			// image gallery slider start
			image_slider: function () { 
				if($('.builtit-img-gallery-slider').length > 0){
				    $('.builtit-img-gallery-slider .swiper-container').each(function(index, element){
				         var meta = $(this).attr('data-slidermeta');
				         var data = meta != undefined ? JSON.parse(meta) : '';
				        var swiper = new Swiper($(this), {
						slidesPerView: data.per_view, 
						spaceBetween: 20,  
						loop: data.loop == 'true' ?  true : false, 
						autoplay: data.autoplay == 'true' ? { delay: parseInt(data.delay) } : false,
						speed: 2000,
						breakpoints: {
							480: {
							  slidesPerView: 1,
							  spaceBetween: 15
							},
							575: {
								slidesPerView: 2,
								spaceBetween: 15
							},
							767: {
								slidesPerView: 2,
								spaceBetween: 30
							},
							991: {
								slidesPerView: 3,
								spaceBetween: 30
							},
							1199: {
								slidesPerView: data.per_view,
								spaceBetween: 30
							},
						},
						pagination: {
							el: '.swiper-pagination',
							clickable: true
						},
						navigation: {
							nextEl: '.swiper-button-next',
							prevEl: '.swiper-button-prev',
						},
					});
				    });
				}
			},
			// image gallery slider end
			// testimonial slider start
			testimonial_slider: function () { 
				if($('.builtit-testimonial-slider').length > 0){
				    var meta = $('.builtit-testimonial-slider .swiper-container').attr('data-slidermeta');
				    var data = meta != undefined ? JSON.parse(meta) : '';
					var swiper = new Swiper('.builtit-testimonial-slider .swiper-container', {
						slidesPerView: 1,
						spaceBetween: 30, 
						loop: data.loop == 'true' ?  true : false, 
						autoplay: data.autoplay == 'true' ? { delay: parseInt(data.delay) } : false,
						speed:2000,
						pagination: {
							el: '.swiper-pagination',
							clickable: true
						},
						navigation: {
							nextEl: '.swiper-button-next',
							prevEl: '.swiper-button-prev',
						},
					});
				}
				if($('.builtit-testimonial-slider2').length > 0){
				    var meta = $('.builtit-testimonial-slider2 .swiper-container').attr('data-slidermeta');
				    var data = meta != undefined ? JSON.parse(meta) : '';
					var swiper = new Swiper('.builtit-testimonial-slider2 .swiper-container', {
						slidesPerView: 1, 
						spaceBetween: 30, 
						loop: data.loop == 'true' ?  true : false, 
						autoplay: data.autoplay == 'true' ? { delay: parseInt(data.delay) } : false,
						speed:2000,
						breakpoints: {
							480: {
							  slidesPerView: 1,
							  spaceBetween: 30
							},
							767: {
								slidesPerView: 1,
								spaceBetween: 30
							},
							991: {
								slidesPerView: 2,
								spaceBetween: 30
							},
							1199: {
								slidesPerView: data.per_view,
								spaceBetween: 30
							},
						},
						pagination: {
							el: '.swiper-pagination',
							clickable: true
						},
						navigation: {
							nextEl: '.swiper-button-next',
							prevEl: '.swiper-button-prev',
						},
					});
				}
				if($('.builtit-testimonial-slider3').length > 0){
				    var meta = $('.builtit-testimonial-slider3 .swiper-container').attr('data-slidermeta');
				    var data = meta != undefined ? JSON.parse(meta) : '';
					var swiper = new Swiper('.builtit-testimonial-slider3 .swiper-container', {
					    slidesPerView: 1, 
						spaceBetween: 30, 
						loop: data.loop == 'true' ?  true : false, 
						autoplay: data.autoplay == 'true' ? { delay: parseInt(data.delay) } : false,
						speed:2000,
						breakpoints: {
							480: {
							  slidesPerView: 1,
							  spaceBetween: 30
							},
							767: {
								slidesPerView: 1,
								spaceBetween: 30
							},
							991: {
								slidesPerView: 2,
								spaceBetween: 30
							},
							1199: {
								slidesPerView: data.per_view,
								spaceBetween: 30
							},
						},
						pagination: {
							el: '.swiper-pagination',
							clickable: true
						},
						navigation: {
							nextEl: '.swiper-button-next',
							prevEl: '.swiper-button-prev',
						},
					});
				}
				if($('.builtit-testimonial-slider4').length > 0){
				    var meta = $('.builtit-testimonial-slider4 .swiper-container').attr('data-slidermeta');
				    var data = meta != undefined ? JSON.parse(meta) : '';
					var swiper = new Swiper('.builtit-testimonial-slider4 .swiper-container', {
					    slidesPerView: 1, 
						spaceBetween: 30, 
						loop: data.loop == 'true' ?  true : false, 
						autoplay: data.autoplay == 'true' ? { delay: parseInt(data.delay) } : false,
						speed:2000,
						breakpoints: {
							480: {
							  slidesPerView: 1,
							  spaceBetween: 30
							},
							767: {
								slidesPerView: 1,
								spaceBetween: 30
							},
							991: {
								slidesPerView: 2,
								spaceBetween: 30
							},
							1199: {
								slidesPerView: data.per_view,
								spaceBetween: 30
							},
						},
						pagination: {
							el: '.swiper-pagination',
							clickable: true
						},
						navigation: {
							nextEl: '.swiper-button-next',
							prevEl: '.swiper-button-prev',
						},
					});
				}
			},
			// testimonial slider end
			// counter start
			counter_timer: function () {
				if($('.builtit-counter-wrapper').length > 0){
					var a = 0;
					$(window).scroll(function() {
						var oTop = $('#counter').offset().top - window.innerHeight;
						if (a == 0 && $(window).scrollTop() > oTop) {
						$('.counter-value').each(function() {
							var $this = $(this),
							countTo = $this.attr('data-count');
							$({
							countNum: $this.text()
							}).animate({
								countNum: countTo
							},
							{
							duration: 5000,
							easing: 'swing',
							step: function() {
							$this.text(Math.floor(this.countNum));
							},
							complete: function() {
							$this.text(this.countNum);
							}
							});
						});
						a = 1;
						}
					});
				};
			},
			// counter end
			// blog slider start
			blog_slider: function () { 
				if($('.builtit-blog-slider').length > 0){
				    $('.builtit-blog-slider .swiper-container').each(function(index, element){
				        var meta = $(this).attr('data-blogmeta');
				        var data = meta != undefined ? JSON.parse(meta) : '';
					    var swiper = new Swiper($(this), {
					    slidesPerView: data.per_view,
						spaceBetween: 30, 
						loop: data.loop == 'true' ?  true : false, 
						autoplay: data.autoplay == 'true' ? { delay: parseInt(data.delay) } : false,
						speed:1000,
						breakpoints: {
							480: {
							  slidesPerView: 1,
							  spaceBetween: 30
							},
							767: {
								slidesPerView: 2,
								spaceBetween: 30
							}, 
							991: {
								slidesPerView: 2,
								spaceBetween: 30
							},
							1199: {
								slidesPerView: data.per_view,
								spaceBetween: 30
							},
						},
						pagination: {
							el: '.swiper-pagination',
							clickable: true
						},
						navigation: {
							nextEl: '.swiper-button-next',
							prevEl: '.swiper-button-prev',
						},
					});
				    });	
				}
			},
			// blog slider end
			// countdown start
    		countdown_timer: function () { 
				if($('.builtit-count-timer-box').length > 0){
					document.addEventListener('readystatechange', event => {
						if (event.target.readyState === "complete") {
							var nsClock = document.getElementsByClassName("nsClock");
						  var countDownDate = new Array();
							for (var i = 0; i < nsClock.length; i++) {
								countDownDate[i] = new Array();
								countDownDate[i]['el'] = nsClock[i];
								countDownDate[i]['time'] = new Date(nsClock[i].getAttribute('data-date')).getTime();
								countDownDate[i]['days'] = 0;
								countDownDate[i]['hours'] = 0;
								countDownDate[i]['seconds'] = 0;
								countDownDate[i]['minutes'] = 0;
							}
						  
						  var countdownfunction = setInterval(function() {
					for (var i = 0; i < countDownDate.length; i++) {
									var now = new Date().getTime();
									var distance = countDownDate[i]['time'] - now;
									 countDownDate[i]['days'] = Math.floor(distance / (1000 * 60 * 60 * 24));
									 countDownDate[i]['hours'] = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
									 countDownDate[i]['minutes'] = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
									 countDownDate[i]['seconds'] = Math.floor((distance % (1000 * 60)) / 1000);
									
									 if (distance < 0) {
										countDownDate[i]['el'].querySelector('.days').innerHTML = 0;
									countDownDate[i]['el'].querySelector('.hours').innerHTML = 0;
									countDownDate[i]['el'].querySelector('.minutes').innerHTML = 0;
									countDownDate[i]['el'].querySelector('.seconds').innerHTML = 0;
									 }else{
					countDownDate[i]['el'].querySelector('.days').innerHTML = countDownDate[i]['days'];
									countDownDate[i]['el'].querySelector('.hours').innerHTML = countDownDate[i]['hours'];
									countDownDate[i]['el'].querySelector('.minutes').innerHTML = countDownDate[i]['minutes'];
									countDownDate[i]['el'].querySelector('.seconds').innerHTML = countDownDate[i]['seconds'];
					}
					  
						 }
								}, 1000);
						}
					});
				}
			},
			// countdown end
			// accordion start
			 accordion: function () {
			if($('.builtit-accordion-box').length > 0){
			     $(".builtit-accordian-title").on("click", function() {
                    if ($(this).hasClass("active")) {
                        $(this).removeClass("active");
                        $(this)
                        .siblings(".collapse")
                        .slideUp(200);
                    } else {
                        $(".builtit-accordian-title").removeClass("active");
                        $(this).addClass("active");
                        $(".collapse").slideUp(200);
                        $(this)
                        .siblings(".collapse")
                        .slideDown(200);
                         }
                     });
			};
		},// accordion end
		// category slider start
			category_slider: function () { 
				if($('.builtit-cat-slider').length > 0){
				    $('.builtit-cat-slider .swiper-container').each(function(index, element){
				    var meta = $(this).attr('data-catmeta');
				    var data = meta != undefined ? JSON.parse(meta) : '';
				    console.log(data);
					var swiper = new Swiper($(this), {
						slidesPerView: 1,
						spaceBetween: 30, 
						loop: data.loop == 'true' ?  true : false, 
						autoplay: data.autoplay == 'true' ? { delay: parseInt(data.delay) } : false,
						speed:2500,
						breakpoints: {
							480: {
							  slidesPerView: 1,
							  spaceBetween: 30
							},
							767: {
								slidesPerView: 2,
								spaceBetween: 30
							},
							991: {
								slidesPerView: 2,
								spaceBetween: 30
							},
							1199: {
								slidesPerView: data.per_view,
								spaceBetween: 30
							},
						},
						pagination: {
							el: '.swiper-pagination',
							clickable: true
						},
						navigation: {
							nextEl: '.swiper-button-next',
							prevEl: '.swiper-button-prev',
						},
					});
				    });	
				}
			},// category slider end
		    
	};	
	builtit.init();
});



